@@ -1,13 +1,17 @@
 # Keep imports sorted alphabetically
+import fabtools.arch
 import fabtools.cron
 import fabtools.deb
+import fabtools.disk
 import fabtools.files
+import fabtools.git
 import fabtools.group
 import fabtools.mysql
 import fabtools.network
 import fabtools.nginx
 import fabtools.nodejs
 import fabtools.openvz
+import fabtools.oracle_jdk
 import fabtools.pkg
 import fabtools.postgres
 import fabtools.python
@@ -15,6 +19,7 @@ import fabtools.python_distribute
 import fabtools.rpm
 import fabtools.service
 import fabtools.shorewall
+import fabtools.ssh
 import fabtools.supervisor
 import fabtools.system
 import fabtools.user
