@@ -4,6 +4,7 @@ Files and directories
 """
 from __future__ import with_statement
 
+from pipes import quote
 import os
 
 from fabric.api import abort, hide, run, settings, sudo, warn
@@ -92,7 +93,7 @@ def mode(path, use_sudo=False):
 
 
 def upload_template(filename, template, context=None, use_sudo=False,
-                  user="root", mkdir=False, chown=False):
+                    user="root", mkdir=False, chown=False):
     """
     Upload a template file.
     """
@@ -103,7 +104,7 @@ def upload_template(filename, template, context=None, use_sudo=False,
         else:
             run('mkdir -p "%s"' % d)
     _upload_template(os.path.join("templates", template), filename,
-                    context=context, use_sudo=use_sudo)
+                     context=context, use_sudo=use_sudo)
     if chown:
         run_as_root('chown %s:%s "%s"' % (user, user, filename))
 
@@ -203,3 +204,16 @@ class watch(object):
                 break
         if self.changed and self.callback:
             self.callback()
+
+
+def uncommented_lines(filename, use_sudo=False):
+    """
+    Get the lines of a remote file, ignoring empty or commented ones
+    """
+    func = run_as_root if use_sudo else run
+    res = func('cat %s' % quote(filename), quiet=True)
+    if res.succeeded:
+        return [line for line in res.splitlines()
+                if line and not line.startswith('#')]
+    else:
+        return []
