@@ -16,7 +16,7 @@ from fabric.api import (
     output,
     settings,
     sudo,
-    )
+)
 from fabric.operations import (
     _AttributeString,
     _execute,
@@ -24,12 +24,17 @@ from fabric.operations import (
     _prefix_env_vars,
     _shell_wrap,
     _sudo_prefix,
-    )
+)
 from fabric.state import default_channel
 from fabric.utils import error
 import fabric.operations
 import fabric.sftp
 
+from fabric.context_managers import (
+    quiet as quiet_manager,
+    warn_only as warn_only_manager,
+)
+
 
 @contextmanager
 def guest(name_or_ctid):
@@ -61,8 +66,9 @@ def guest(name_or_ctid):
     _orig_run_command = fabric.operations._run_command
     _orig_put = fabric.sftp.SFTP.put
 
-    def run_guest_command(command, shell=True, pty=False,
-        combine_stderr=True, sudo=False, user=None):
+    def run_guest_command(command, shell=True, pty=True, combine_stderr=True,
+        sudo=False, user=None, quiet=False, warn_only=False, stdout=None,
+        stderr=None, group=None, timeout=None):
         """
         Run command inside a guest container
         """
@@ -171,61 +177,79 @@ def guest(name_or_ctid):
     fabric.sftp.SFTP.put = _orig_put
 
 
-def _run_host_command(command, shell=True, pty=True, combine_stderr=True):
+@contextmanager
+def _noop():
+    yield
+
+
+def _run_host_command(command, shell=True, pty=True, combine_stderr=True,
+    quiet=False, warn_only=False, stdout=None, stderr=None, timeout=None):
     """
     Run host wrapper command as root
 
     (Modified from fabric.operations._run_command to ignore prefixes,
     path(), cd(), and always use sudo.)
     """
-    # Set up new var so original argument can be displayed verbatim later.
-    given_command = command
-    # Handle context manager modifications, and shell wrapping
-    wrapped_command = _shell_wrap(
-        command,
-        shell,
-        _sudo_prefix(None)
-    )
-    # Execute info line
-    if output.debug:
-        print("[%s] %s: %s" % (env.host_string, 'sudo', wrapped_command))
-    elif output.running:
-        print("[%s] %s: %s" % (env.host_string, 'sudo', given_command))
-
-    # Actual execution, stdin/stdout/stderr handling, and termination
-    stdout, stderr, status = _execute(default_channel(), wrapped_command, pty,
-                                      combine_stderr)
-
-    # Assemble output string
-    out = _AttributeString(stdout)
-    err = _AttributeString(stderr)
-
-    # Error handling
-    out.failed = False
-    if status != 0:
-        out.failed = True
-        msg = "%s() received nonzero return code %s while executing" % (
-            'sudo', status
+    manager = _noop
+    if warn_only:
+        manager = warn_only_manager
+    # Quiet's behavior is a superset of warn_only's, so it wins.
+    if quiet:
+        manager = quiet_manager
+    with manager():
+        # Set up new var so original argument can be displayed verbatim later.
+        given_command = command
+        # Handle context manager modifications, and shell wrapping
+        wrapped_command = _shell_wrap(
+            command,    # !! removed _prefix_commands() & _prefix_env_vars()
+            shell,
+            _sudo_prefix(None)  # !! always use sudo
         )
-        if env.warn_only:
-            msg += " '%s'!" % given_command
-        else:
-            msg += "!\n\nRequested: %s\nExecuted: %s" % (
-                given_command, wrapped_command
+        # Execute info line
+        which = 'sudo'          # !! always use sudo
+        if output.debug:
+            print("[%s] %s: %s" % (env.host_string, which, wrapped_command))
+        elif output.running:
+            print("[%s] %s: %s" % (env.host_string, which, given_command))
+
+        # Actual execution, stdin/stdout/stderr handling, and termination
+        result_stdout, result_stderr, status = _execute(
+            channel=default_channel(), command=wrapped_command, pty=pty,
+            combine_stderr=combine_stderr, invoke_shell=False, stdout=stdout,
+            stderr=stderr, timeout=timeout)
+
+        # Assemble output string
+        out = _AttributeString(result_stdout)
+        err = _AttributeString(result_stderr)
+
+        # Error handling
+        out.failed = False
+        out.command = given_command
+        out.real_command = wrapped_command
+        if status not in env.ok_ret_codes:
+            out.failed = True
+            msg = "%s() received nonzero return code %s while executing" % (
+                which, status
             )
-        error(message=msg, stdout=out, stderr=err)
+            if env.warn_only:
+                msg += " '%s'!" % given_command
+            else:
+                msg += "!\n\nRequested: %s\nExecuted: %s" % (
+                    given_command, wrapped_command
+                )
+            error(message=msg, stdout=out, stderr=err)
 
-    # Attach return code to output string so users who have set things to
-    # warn only, can inspect the error code.
-    out.return_code = status
+        # Attach return code to output string so users who have set things to
+        # warn only, can inspect the error code.
+        out.return_code = status
 
-    # Convenience mirror of .failed
-    out.succeeded = not out.failed
+        # Convenience mirror of .failed
+        out.succeeded = not out.failed
 
-    # Attach stderr for anyone interested in that.
-    out.stderr = err
+        # Attach stderr for anyone interested in that.
+        out.stderr = err
 
-    return out
+        return out
 
 
 def _shell_wrap_inner(command, shell=True, sudo_prefix=None):
@@ -248,7 +272,7 @@ def _shell_wrap_inner(command, shell=True, sudo_prefix=None):
     # then quote it. Otherwise, empty string.
     if shell:
         shell = env.shell + " "
-        command = '"%s"' % command
+        command = '"%s"' % command    # !! removed _shell_escape() here
     else:
         shell = ""
     # Resulting string should now have correct formatting
