@@ -8,16 +8,16 @@ This module provides tools for installing `Oracle JDK`_
 
 """
 from __future__ import with_statement
+
 import re
 
 from fabric.api import run, cd, settings, hide
 
-from fabtools import system
-from fabtools.require.files import directory as require_directory
-from fabtools.require.files import file as require_file
+from fabtools.files import is_link
+from fabtools.system import get_arch
 
 
-DEFAULT_VERSION = '7u17-b02'
+DEFAULT_VERSION = '7u21-b11'
 
 
 def install_from_oracle_site(version=DEFAULT_VERSION):
@@ -33,6 +33,8 @@ def install_from_oracle_site(version=DEFAULT_VERSION):
 
     """
 
+    from fabtools.require.files import directory as require_directory
+
     release, build = version.split('-')
     major, update = release.split('u')
     if len(update) == 1:
@@ -40,7 +42,10 @@ def install_from_oracle_site(version=DEFAULT_VERSION):
 
     jdk_arch = _required_jdk_arch()
 
-    jdk_filename = 'jdk-%(release)s-linux-%(jdk_arch)s.tar.gz' % locals()
+    if major == '6':
+        jdk_filename = 'jdk-%(release)s-linux-%(jdk_arch)s.bin' % locals()
+    else:
+        jdk_filename = 'jdk-%(release)s-linux-%(jdk_arch)s.tar.gz' % locals()
     jdk_dir = 'jdk1.%(major)s.0_%(update)s' % locals()
 
     jdk_url = 'http://download.oracle.com/otn-pub/java/jdk/' +\
@@ -54,7 +59,16 @@ def install_from_oracle_site(version=DEFAULT_VERSION):
 
     require_directory('/opt', mode='777', use_sudo=True)
     with cd('/opt'):
-        run('tar -xzvf /tmp/%s' % jdk_filename)
+        if major == '6':
+            run('chmod u+x /tmp/%s' % jdk_filename)
+            with cd('/tmp'):
+                run('./%s' % jdk_filename)
+                run('mv %s /opt/' % jdk_dir)
+        else:
+            run('tar -xzvf /tmp/%s' % jdk_filename)
+
+        if is_link('jdk'):
+            run('rm -rf jdk')
         run('ln -s %s jdk' % jdk_dir)
 
     _create_profile_d_file()
@@ -64,6 +78,8 @@ def _create_profile_d_file():
     """
     Create profile.d file with Java environment variables set.
     """
+    from fabtools.require.files import file as require_file
+
     require_file('/etc/profile.d/java.sh', contents=
                  'export JAVA_HOME="/opt/jdk"\n' +
                  'export PATH="$JAVA_HOME/bin:$PATH"\n',
@@ -76,7 +92,7 @@ def version():
 
     Returns ``None`` if it is not installed.
     """
-    with settings(hide('running', 'stdout'), warn_only=True):
+    with settings(hide('running', 'stdout', 'warnings'), warn_only=True):
         res = run('java -version')
     if res.failed:
         return None
@@ -91,7 +107,7 @@ def _required_jdk_arch():
 
     Raises exception when current system architecture is unsupported.
     """
-    system_arch = system.get_arch()
+    system_arch = get_arch()
     if system_arch == 'x86_64':
         return 'x64'
     elif re.match('i[0-9]86', system_arch):
