@@ -13,13 +13,14 @@ from __future__ import with_statement
 
 from contextlib import contextmanager
 from distutils.version import StrictVersion as V
+from pipes import quote
 import os
 import posixpath
 
 from fabric.api import cd, hide, prefix, run, settings, sudo
 from fabric.utils import puts
 
-from fabtools.utils import run_as_root
+from fabtools.utils import abspath, run_as_root
 
 
 def is_pip_installed(version=None):
@@ -59,7 +60,7 @@ def install_pip():
     """
     with cd('/tmp'):
         run('curl --silent -O https://raw.github.com/pypa/pip/master/contrib/get-pip.py')
-        run_as_root('python get-pip.py')
+        run_as_root('python get-pip.py', pty=False)
 
 
 def is_installed(package):
@@ -75,7 +76,7 @@ def is_installed(package):
 
 
 def install(packages, upgrade=False, use_mirrors=True, use_sudo=False,
-            user=None, download_cache=None):
+            user=None, download_cache=None, quiet=False):
     """
     Install Python package(s) using `pip`_.
 
@@ -101,16 +102,19 @@ def install(packages, upgrade=False, use_mirrors=True, use_sudo=False,
         options.append('--upgrade')
     if download_cache:
         options.append('--download-cache="%s"' % download_cache)
+    if quiet:
+        options.append('--quiet')
     options = ' '.join(options)
     command = 'pip install %(options)s %(packages)s' % locals()
     if use_sudo:
-        sudo(command, user=user)
+        sudo(command, user=user, pty=False)
     else:
-        run(command)
+        run(command, pty=False)
 
 
 def install_requirements(filename, upgrade=False, use_mirrors=True,
-                         use_sudo=False, user=None, download_cache=None):
+                         use_sudo=False, user=None, download_cache=None,
+                         quiet=False):
     """
     Install Python packages from a pip `requirements file`_.
 
@@ -129,12 +133,14 @@ def install_requirements(filename, upgrade=False, use_mirrors=True,
         options.append('--upgrade')
     if download_cache:
         options.append('--download-cache="%s"' % download_cache)
+    if quiet:
+        options.append('--quiet')
     options = ' '.join(options)
     command = 'pip install %(options)s -r %(filename)s' % locals()
     if use_sudo:
-        sudo(command, user=user)
+        sudo(command, user=user, pty=False)
     else:
-        run(command)
+        run(command, pty=False)
 
 
 @contextmanager
@@ -152,6 +158,13 @@ def virtualenv(directory, local=False):
 
     .. _virtual environment: http://www.virtualenv.org/
     """
-    join = os.path.join if local else posixpath.join
-    with prefix('. "%s"' % join(directory, 'bin', 'activate')):
+
+    path_mod = os.path if local else posixpath
+
+    # Build absolute path to the virtualenv activation script
+    venv_path = abspath(directory)
+    activate_path = path_mod.join(venv_path, 'bin', 'activate')
+
+    # Source the activation script
+    with prefix('. %s' % quote(activate_path)):
         yield
