@@ -12,11 +12,12 @@ from __future__ import with_statement
 from fabric.api import cd, run, settings
 
 from fabtools.files import is_file, watch
+from fabtools.system import distrib_family
 from fabtools.utils import run_as_root
 import fabtools.supervisor
 
 
-VERSION = '2.6.11'
+VERSION = '2.6.13'
 
 BINARIES = [
     'redis-benchmark',
@@ -37,9 +38,24 @@ def installed_from_source(version=VERSION):
     from fabtools.require import directory as require_directory
     from fabtools.require import file as require_file
     from fabtools.require import user as require_user
-    from fabtools.require.deb import package as require_package
+    from fabtools.require.deb import packages as require_deb_packages
+    from fabtools.require.rpm import packages as require_rpm_packages
 
-    require_user('redis', home='/var/lib/redis')
+    family = distrib_family()
+
+    if family == 'debian':
+        require_deb_packages([
+            'build-essential',
+        ])
+
+    elif family == 'redhat':
+        require_rpm_packages([
+            'gcc',
+            'make',
+        ])
+
+    require_user('redis', home='/var/lib/redis', system=True)
+    require_directory('/var/lib/redis', owner='redis', use_sudo=True)
 
     dest_dir = '/opt/redis-%(version)s' % locals()
     require_directory(dest_dir, use_sudo=True, owner='redis')
@@ -55,7 +71,6 @@ def installed_from_source(version=VERSION):
             run('tar xzf %(tarball)s' % locals())
 
             # Compile and install binaries
-            require_package('build-essential')
             with cd('redis-%(version)s' % locals()):
                 run('make')
 
@@ -112,7 +127,8 @@ def instance(name, version=VERSION, **kwargs):
     params.setdefault('port', '6379')
     params.setdefault('logfile', '/var/log/redis/redis-%(name)s.log' % locals())
     params.setdefault('loglevel', 'verbose')
-    params.setdefault('dbfilename', '/var/db/redis/redis-%(name)s-dump.rdb' % locals())
+    params.setdefault('dir', '/var/db/redis')
+    params.setdefault('dbfilename', 'redis-%(name)s-dump.rdb' % locals())
     params.setdefault('save', ['900 1', '300 10', '60 10000'])
 
     # Build config file from parameters
